==> GO_1.16.0.tar.gz: GO/man/GOBPPARENTS.Rd <==
\name{GOBPPARENTS}
\alias{GOBPPARENTS}
\title{Annotation of GO Identifiers to their Biological Process Parents} 
\description{
  This data set describes associations between GO molecular function (BP)
  terms and their direct parent BP terms, based on the directed acyclic
  graph (DAG) defined by the Gene Ontology Consortium. The format is an R
  environment mapping the GO BP terms to all direct parent terms, where a
  direct parent term is a more general GO term that immediately precedes
  the given GO term in the DAG.
}
\details{
   Each GO BP term is mapped to a named vector of GO BP terms. The name
  associated with the parent term will be either \emph{isa}, \emph{hasa} or \emph{partof},
  where \emph{isa} indicates that the child term is a more specific version
  of the parent, and \emph{hasa} and \emph{partof} indicate that the
  child term is a part of the parent. For example, a telomere is part of
  a chromosome.

  Biological process is defined as the broad biological goals, such as
  mitosis or purine metabolism, that are accomplished by ordered
  assemblies of molecular functions as defined by Gene Ontology
  Consortium.

  Mappings were based on data provided:

  Gene Ontology:\\url{http://gopher5/compbio/annotationSourceData/archive.godatabase.org/latest/}. Built: 08-Feb-2007
  
  Package built: Fri Mar  2 13:37:12 2007
}
\references{
\url{http://www.geneontology.org/} and
\url{http://www.ncbi.nlm.nih.gov/entrez/query.fcgi?db=gene} 
}
\examples{
  require("GO", character.only = TRUE) || stop("GO unavailable")
  require("annotate", character.only = TRUE) || stop("annotate unavailable")
  # Convert the environment object to a list
  xx <- as.list(GOBPPARENTS)
  # Remove GO IDs that do not have any parent
  xx <- xx[!is.na(xx)]
  if(length(xx) > 0){
     # Get the children GO IDs for the first elents of xx
        goids <- xx[[1]]
        # Find out the GO terms for the first parent goid
        GOID(GOTERM[[goids[1]]])
        Term(GOTERM[[goids[1]]])
        Synonym(GOTERM[[goids[1]]])
        Secondary(GOTERM[[goids[1]]])
        Definition(GOTERM[[goids[1]]])
        Ontology(GOTERM[[goids[1]]])
  }
}
\keyword{datasets}

==> GO_2.0.1.tar.gz: GO/man/GOBPPARENTS.Rd <==
\name{GOBPPARENTS}
\alias{GOBPPARENTS}
\title{Annotation of GO Identifiers to their Biological Process Parents} 
\description{
  This data set describes associations between GO molecular function (BP)
  terms and their direct parent BP terms, based on the directed acyclic
  graph (DAG) defined by the Gene Ontology Consortium. The format is an R
  environment mapping the GO BP terms to all direct parent terms, where a
  direct parent term is a more general GO term that immediately precedes
  the given GO term in the DAG.
}
\details{
   Each GO BP term is mapped to a named vector of GO BP terms. The name
  associated with the parent term will be either \emph{isa}, \emph{hasa} or \emph{partof},
  where \emph{isa} indicates that the child term is a more specific version
  of the parent, and \emph{hasa} and \emph{partof} indicate that the
  child term is a part of the parent. For example, a telomere is part of
  a chromosome.

  Biological process is defined as the broad biological goals, such as
  mitosis or purine metabolism, that are accomplished by ordered
  assemblies of molecular functions as defined by Gene Ontology
  Consortium.

  Mappings were based on data provided:

  Gene Ontology:\\url{ftp://ftp.geneontology.org/pub/go/godatabase/archive/latest}. Built: Build Information not available
  
  Package built: Wed Aug 29 09:09:17 2007
}
\references{
\url{http://www.geneontology.org/} and
\url{http://www.ncbi.nlm.nih.gov/entrez/query.fcgi?db=gene} 
}
\examples{
  require("GO", character.only = TRUE) || stop("GO unavailable")
  require("annotate", character.only = TRUE) || stop("annotate unavailable")
  # Convert the environment object to a list
  xx <- as.list(GOBPPARENTS)
  # Remove GO IDs that do not have any parent
  xx <- xx[!is.na(xx)]
  if(length(xx) > 0){
     # Get the children GO IDs for the first elents of xx
        goids <- xx[[1]]
        # Find out the GO terms for the first parent goid
        GOID(GOTERM[[goids[1]]])
        Term(GOTERM[[goids[1]]])
        Synonym(GOTERM[[goids[1]]])
        Secondary(GOTERM[[goids[1]]])
        Definition(GOTERM[[goids[1]]])
        Ontology(GOTERM[[goids[1]]])
  }
}
\keyword{datasets}
